@@ -45,7 +45,7 @@ use Text::Wrap::Smart ':all';
 binmode(STDOUT, ":encoding(UTF-8)");
 
 BEGIN {
-    our $VERSION = 1.23;
+    our $VERSION = 1.24;
 }
 
 sub ansi_output {
@@ -54,13 +54,13 @@ sub ansi_output {
     my $delay = shift;
 
     if (length($text) > 1) {
-		while ($text =~ /\[\%\s+BOX (.*?),(\d+),(\d+),(\d+),(\d+),(.*?)\s+\%\](.*?)\[\%\s+ENDBOX\s+\%\]/i) {
-			my $replace = $self->box($1,$2,$3,$4,$5,$6,$7);
-			$text =~ s/\[\%\s+BOX.*?\%\].*?\[\%\s+ENDBOX.*?\%\]/$replace/i;
-		}
+        while ($text =~ /\[\%\s+BOX (.*?),(\d+),(\d+),(\d+),(\d+),(.*?)\s+\%\](.*?)\[\%\s+ENDBOX\s+\%\]/i) {
+            my $replace = $self->box($1, $2, $3, $4, $5, $6, $7);
+            $text =~ s/\[\%\s+BOX.*?\%\].*?\[\%\s+ENDBOX.*?\%\]/$replace/i;
+        }
         foreach my $string (keys %{ $self->{'ansi_sequences'} }) {
             if ($string =~ /CLEAR|CLS/i) {
-                my $ch = locate(1,1) . cls;
+                my $ch = locate(1, 1) . cls;
                 $text =~ s/\[\%\s+$string\s+\%\]/$ch/gi;
             } else {
                 $text =~ s/\[\%\s+$string\s+\%\]/$self->{'ansi_sequences'}->{$string}/gi;
@@ -94,178 +94,178 @@ sub ansi_output {
 } ## end sub ansi_output
 
 sub box {
-	my $self   = shift;
-	my $color  = '[% ' . shift . ' %]';
-	my $x      = shift;
-	my $y      = shift;
-	my $w      = shift;
-	my $h      = shift;
-	my $type   = shift;
-	my $string = shift;
+    my $self   = shift;
+    my $color  = '[% ' . shift . ' %]';
+    my $x      = shift;
+    my $y      = shift;
+    my $w      = shift;
+    my $h      = shift;
+    my $type   = shift;
+    my $string = shift;
 
-	my $tl  = '╔';
-	my $tr  = '╗';
-	my $bl  = '╚';
-	my $br  = '╝';
-	my $mid = '═';
-	my $v   = '║';
-	if ($type =~ /THIN/i) {
-		$tl  = '┌';
-		$tr  = '┐';
-		$bl  = '└';
-		$br  = '┘';
-		$mid = '─';
-		$v   = '│';
-	} elsif ($type =~ /ROUND/i) {
-		$tl  = '╭';
-		$tr  = '╮';
-		$bl  = '╰';
-		$br  = '╯';
-		$mid = '─';
-		$v   = '│';
-	} elsif ($type =~ /THICK/i) {
-		$tl  = '┏';
-		$tr  = '┓';
-		$bl  = '┗';
-		$br  = '┛';
-		$mid = '━';
-		$v   = '┃';
+    my $tl  = '╔';
+    my $tr  = '╗';
+    my $bl  = '╚';
+    my $br  = '╝';
+    my $mid = '═';
+    my $v   = '║';
+    if ($type =~ /THIN/i) {
+        $tl  = '┌';
+        $tr  = '┐';
+        $bl  = '└';
+        $br  = '┘';
+        $mid = '─';
+        $v   = '│';
+    } elsif ($type =~ /ROUND/i) {
+        $tl  = '╭';
+        $tr  = '╮';
+        $bl  = '╰';
+        $br  = '╯';
+        $mid = '─';
+        $v   = '│';
+    } elsif ($type =~ /THICK/i) {
+        $tl  = '┏';
+        $tr  = '┓';
+        $bl  = '┗';
+        $br  = '┛';
+        $mid = '━';
+        $v   = '┃';
+    } ## end elsif ($type =~ /THICK/i)
+    my $text = '';
+    my $xx   = $x;
+    my $yy   = $y;
+    $text .= locate($yy++, $xx) . $color . $tl . $mid x ($w - 2) . $tr . '[% RESET %]';
+    foreach my $count (1 .. ($h - 2)) {
+        $text .= locate($yy++, $xx) . $color . $v . '[% RESET %]' . ' ' x ($w - 2) . $color . $v . '[% RESET %]';
     }
-	my $text = '';
-	my $xx = $x;
-	my $yy = $y;
-    $text .= locate($yy++,$xx) . $color . $tl . $mid x ($w - 2) . $tr . '[% RESET %]';
-	foreach my $count (1 .. ($h - 2)) {
-		$text .= locate($yy++,$xx) . $color . $v . '[% RESET %]' . ' ' x ($w - 2) . $color . $v . '[% RESET %]';
-	}
-    $text .= locate($yy++,$xx) . $color . $bl . $mid x ($w - 2) . $br . '[% RESET %]' . $self->{'ansi_sequences'}->{'SAVE'};
-	$text .= locate($y+1,$x+1);
-	chomp(my @lines = fuzzy_wrap($string,($w - 3)));
-	$xx = $x+1;
-	$yy = $y+1;
-	foreach my $line (@lines) {
-		$text .= locate($yy++,$xx) . $line;
-	}
-	$text .= $self->{'ansi_sequences'}->{'RESTORE'};
-	return($text);
-}
+    $text .= locate($yy++,  $xx) . $color . $bl . $mid x ($w - 2) . $br . '[% RESET %]' . $self->{'ansi_sequences'}->{'SAVE'};
+    $text .= locate($y + 1, $x + 1);
+    chomp(my @lines = fuzzy_wrap($string, ($w - 3)));
+    $xx = $x + 1;
+    $yy = $y + 1;
+    foreach my $line (@lines) {
+        $text .= locate($yy++, $xx) . $line;
+    }
+    $text .= $self->{'ansi_sequences'}->{'RESTORE'};
+    return ($text);
+} ## end sub box
 
 sub new {
     my $class = shift;
 
     my $esc = chr(27) . '[';
 
-	my $self = {
-		'ansi_prefix' => $esc,
-		'mode'        => 'long',
-		'ansi_sequences' => {
-			'RETURN'   => chr(13),
-			'LINEFEED' => chr(10),
-			'NEWLINE'  => chr(13) . chr(10),
+    my $self = {
+        'ansi_prefix'    => $esc,
+        'mode'           => 'long',
+        'ansi_sequences' => {
+            'RETURN'   => chr(13),
+            'LINEFEED' => chr(10),
+            'NEWLINE'  => chr(13) . chr(10),
 
-			'CLEAR'      => locate(1, 1) . cls,
-			'CLS'        => locate(1, 1) . cls,
-			'CLEAR LINE' => clline,
-			'CLEAR DOWN' => cldown,
-			'CLEAR UP'   => clup,
+            'CLEAR'      => locate(1, 1) . cls,
+            'CLS'        => locate(1, 1) . cls,
+            'CLEAR LINE' => clline,
+            'CLEAR DOWN' => cldown,
+            'CLEAR UP'   => clup,
 
-			# Cursor
-			'UP'          => $esc . 'A',
-			'DOWN'        => $esc . 'B',
-			'RIGHT'       => $esc . 'C',
-			'LEFT'        => $esc . 'D',
-			'SAVE'        => $esc . 's',
-			'RESTORE'     => $esc . 'u',
-			'RESET'       => $esc . '0m',
+            # Cursor
+            'UP'      => $esc . 'A',
+            'DOWN'    => $esc . 'B',
+            'RIGHT'   => $esc . 'C',
+            'LEFT'    => $esc . 'D',
+            'SAVE'    => $esc . 's',
+            'RESTORE' => $esc . 'u',
+            'RESET'   => $esc . '0m',
 
-			# Attributes
-			'BOLD'         => $esc . '1m',
-			'FAINT'        => $esc . '2m',
-			'ITALIC'       => $esc . '3m',
-			'UNDERLINE'    => $esc . '4m',
-			'OVERLINE'     => $esc . '53m',
-			'SLOW BLINK'   => $esc . '5m',
-			'RAPID BLINK'  => $esc . '6m',
-			'INVERT'       => $esc . '7m',
-			'REVERSE'      => $esc . '7m',
-			'CROSSED OUT'  => $esc . '9m',
-			'DEFAULT FONT' => $esc . '10m',
-			'FONT1'        => $esc . '11m',
-			'FONT2'        => $esc . '12m',
-			'FONT3'        => $esc . '13m',
-			'FONT4'        => $esc . '14m',
-			'FONT5'        => $esc . '15m',
-			'FONT6'        => $esc . '16m',
-			'FONT7'        => $esc . '17m',
-			'FONT8'        => $esc . '18m',
-			'FONT9'        => $esc . '19m',
+            # Attributes
+            'BOLD'         => $esc . '1m',
+            'FAINT'        => $esc . '2m',
+            'ITALIC'       => $esc . '3m',
+            'UNDERLINE'    => $esc . '4m',
+            'OVERLINE'     => $esc . '53m',
+            'SLOW BLINK'   => $esc . '5m',
+            'RAPID BLINK'  => $esc . '6m',
+            'INVERT'       => $esc . '7m',
+            'REVERSE'      => $esc . '7m',
+            'CROSSED OUT'  => $esc . '9m',
+            'DEFAULT FONT' => $esc . '10m',
+            'FONT1'        => $esc . '11m',
+            'FONT2'        => $esc . '12m',
+            'FONT3'        => $esc . '13m',
+            'FONT4'        => $esc . '14m',
+            'FONT5'        => $esc . '15m',
+            'FONT6'        => $esc . '16m',
+            'FONT7'        => $esc . '17m',
+            'FONT8'        => $esc . '18m',
+            'FONT9'        => $esc . '19m',
 
-			# Color
-			'NORMAL' => $esc . '22m',
+            # Color
+            'NORMAL' => $esc . '22m',
 
-			# Foreground color
-			'BLACK'          => $esc . '30m',
-			'RED'            => $esc . '31m',
-			'PINK'           => $esc . '38;5;198m',
-			'ORANGE'         => $esc . '38;5;202m',
-			'NAVY'           => $esc . '38;5;17m',
-			'GREEN'          => $esc . '32m',
-			'YELLOW'         => $esc . '33m',
-			'BLUE'           => $esc . '34m',
-			'MAGENTA'        => $esc . '35m',
-			'CYAN'           => $esc . '36m',
-			'WHITE'          => $esc . '37m',
-			'DEFAULT'        => $esc . '39m',
-			'BRIGHT BLACK'   => $esc . '90m',
-			'BRIGHT RED'     => $esc . '91m',
-			'BRIGHT GREEN'   => $esc . '92m',
-			'BRIGHT YELLOW'  => $esc . '93m',
-			'BRIGHT BLUE'    => $esc . '94m',
-			'BRIGHT MAGENTA' => $esc . '95m',
-			'BRIGHT CYAN'    => $esc . '96m',
-			'BRIGHT WHITE'   => $esc . '97m',
+            # Foreground color
+            'BLACK'          => $esc . '30m',
+            'RED'            => $esc . '31m',
+            'PINK'           => $esc . '38;5;198m',
+            'ORANGE'         => $esc . '38;5;202m',
+            'NAVY'           => $esc . '38;5;17m',
+            'GREEN'          => $esc . '32m',
+            'YELLOW'         => $esc . '33m',
+            'BLUE'           => $esc . '34m',
+            'MAGENTA'        => $esc . '35m',
+            'CYAN'           => $esc . '36m',
+            'WHITE'          => $esc . '37m',
+            'DEFAULT'        => $esc . '39m',
+            'BRIGHT BLACK'   => $esc . '90m',
+            'BRIGHT RED'     => $esc . '91m',
+            'BRIGHT GREEN'   => $esc . '92m',
+            'BRIGHT YELLOW'  => $esc . '93m',
+            'BRIGHT BLUE'    => $esc . '94m',
+            'BRIGHT MAGENTA' => $esc . '95m',
+            'BRIGHT CYAN'    => $esc . '96m',
+            'BRIGHT WHITE'   => $esc . '97m',
 
-			# Background color
-			'B_BLACK'          => $esc . '40m',
-			'B_RED'            => $esc . '41m',
-			'B_GREEN'          => $esc . '42m',
-			'B_YELLOW'         => $esc . '43m',
-			'B_BLUE'           => $esc . '44m',
-			'B_MAGENTA'        => $esc . '45m',
-			'B_CYAN'           => $esc . '46m',
-			'B_WHITE'          => $esc . '47m',
-			'B_DEFAULT'        => $esc . '49m',
-			'B_PINK'           => $esc . '48;5;198m',
-			'B_ORANGE'         => $esc . '48;5;202m',
-			'B_NAVY'           => $esc . '48;5;17m',
-			'BRIGHT B_BLACK'   => $esc . '100m',
-			'BRIGHT B_RED'     => $esc . '101m',
-			'BRIGHT B_GREEN'   => $esc . '102m',
-			'BRIGHT B_YELLOW'  => $esc . '103m',
-			'BRIGHT B_BLUE'    => $esc . '104m',
-			'BRIGHT B_MAGENTA' => $esc . '105m',
-			'BRIGHT B_CYAN'    => $esc . '106m',
-			'BRIGHT B_WHITE'   => $esc . '107m',
+            # Background color
+            'B_BLACK'          => $esc . '40m',
+            'B_RED'            => $esc . '41m',
+            'B_GREEN'          => $esc . '42m',
+            'B_YELLOW'         => $esc . '43m',
+            'B_BLUE'           => $esc . '44m',
+            'B_MAGENTA'        => $esc . '45m',
+            'B_CYAN'           => $esc . '46m',
+            'B_WHITE'          => $esc . '47m',
+            'B_DEFAULT'        => $esc . '49m',
+            'B_PINK'           => $esc . '48;5;198m',
+            'B_ORANGE'         => $esc . '48;5;202m',
+            'B_NAVY'           => $esc . '48;5;17m',
+            'BRIGHT B_BLACK'   => $esc . '100m',
+            'BRIGHT B_RED'     => $esc . '101m',
+            'BRIGHT B_GREEN'   => $esc . '102m',
+            'BRIGHT B_YELLOW'  => $esc . '103m',
+            'BRIGHT B_BLUE'    => $esc . '104m',
+            'BRIGHT B_MAGENTA' => $esc . '105m',
+            'BRIGHT B_CYAN'    => $esc . '106m',
+            'BRIGHT B_WHITE'   => $esc . '107m',
 
-			'HORIZONTAL RULE ORANGE'         => "\r" . $esc . '48;5;202m' . clline . $esc . '0m',
-			'HORIZONTAL RULE PINK'           => "\r" . $esc . '48;5;198m' . clline . $esc . '0m',
-			'HORIZONTAL RULE RED'            => "\r" . $esc . '41m'       . clline . $esc . '0m',
-			'HORIZONTAL RULE BRIGHT RED'     => "\r" . $esc . '101m'      . clline . $esc . '0m',
-			'HORIZONTAL RULE GREEN'          => "\r" . $esc . '42m'       . clline . $esc . '0m',
-			'HORIZONTAL RULE BRIGHT GREEN'   => "\r" . $esc . '102m'      . clline . $esc . '0m',
-			'HORIZONTAL RULE YELLOW'         => "\r" . $esc . '43m'       . clline . $esc . '0m',
-			'HORIZONTAL RULE BRIGHT YELLOW'  => "\r" . $esc . '103m'      . clline . $esc . '0m',
-			'HORIZONTAL RULE BLUE'           => "\r" . $esc . '44m'       . clline . $esc . '0m',
-			'HORIZONTAL RULE BRIGHT BLUE'    => "\r" . $esc . '104m'      . clline . $esc . '0m',
-			'HORIZONTAL RULE MAGENTA'        => "\r" . $esc . '45m'       . clline . $esc . '0m',
-			'HORIZONTAL RULE BRIGHT MAGENTA' => "\r" . $esc . '105m'      . clline . $esc . '0m',
-			'HORIZONTAL RULE CYAN'           => "\r" . $esc . '46m'       . clline . $esc . '0m',
-			'HORIZONTAL RULE BRIGHT CYAN'    => "\r" . $esc . '106m'      . clline . $esc . '0m',
-			'HORIZONTAL RULE WHITE'          => "\r" . $esc . '47m'       . clline . $esc . '0m',
-			'HORIZONTAL RULE BRIGHT WHITE'   => "\r" . $esc . '107m'      . clline . $esc . '0m',
-		},
-		@_,
-	};
+            'HORIZONTAL RULE ORANGE'         => "\r" . $esc . '48;5;202m' . clline . $esc . '0m',
+            'HORIZONTAL RULE PINK'           => "\r" . $esc . '48;5;198m' . clline . $esc . '0m',
+            'HORIZONTAL RULE RED'            => "\r" . $esc . '41m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BRIGHT RED'     => "\r" . $esc . '101m' . clline . $esc . '0m',
+            'HORIZONTAL RULE GREEN'          => "\r" . $esc . '42m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BRIGHT GREEN'   => "\r" . $esc . '102m' . clline . $esc . '0m',
+            'HORIZONTAL RULE YELLOW'         => "\r" . $esc . '43m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BRIGHT YELLOW'  => "\r" . $esc . '103m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BLUE'           => "\r" . $esc . '44m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BRIGHT BLUE'    => "\r" . $esc . '104m' . clline . $esc . '0m',
+            'HORIZONTAL RULE MAGENTA'        => "\r" . $esc . '45m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BRIGHT MAGENTA' => "\r" . $esc . '105m' . clline . $esc . '0m',
+            'HORIZONTAL RULE CYAN'           => "\r" . $esc . '46m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BRIGHT CYAN'    => "\r" . $esc . '106m' . clline . $esc . '0m',
+            'HORIZONTAL RULE WHITE'          => "\r" . $esc . '47m' . clline . $esc . '0m',
+            'HORIZONTAL RULE BRIGHT WHITE'   => "\r" . $esc . '107m' . clline . $esc . '0m',
+        },
+        @_,
+    };
 
     # Generate generic colors
     foreach my $count (0 .. 255) {
@@ -278,51 +278,51 @@ sub new {
         }
     } ## end foreach my $count (0 .. 255)
 
-	# 20D0 - 20EF
-	# 2100 - 218B
-	# 2190 - 23FF
-	# 2500 - 27FF
-	# 2900 - 2BFE
-	# 3001 - 3030
-	# 1F300 - 1F5FF
-	# 1F600 - 1F64F
-	# 1F680 - 1F6F8
-	# 1F780 - 1F7D8
-	# 1F800 - 1F8B1
-	# 1F900 - 1F997
-	# 1F9D0 - 1F9E6
+    # 20D0 - 20EF
+    # 2100 - 218B
+    # 2190 - 23FF
+    # 2500 - 27FF
+    # 2900 - 2BFE
+    # 3001 - 3030
+    # 1F300 - 1F5FF
+    # 1F600 - 1F64F
+    # 1F680 - 1F6F8
+    # 1F780 - 1F7D8
+    # 1F800 - 1F8B1
+    # 1F900 - 1F997
+    # 1F9D0 - 1F9E6
 
     # Generate symbols
-	my $start = 0x2400;
-	my $finish = 0x2605;
-	if ($self->{'mode'} =~ /full|long/i) {
-		$start  = 0x2010;
-		$finish = 0x2BFF;
-	}
+    my $start  = 0x2400;
+    my $finish = 0x2605;
+    if ($self->{'mode'} =~ /full|long/i) {
+        $start  = 0x2010;
+        $finish = 0x2BFF;
+    }
 
-	my $name = charnames::viacode(0x1F341); # Maple Leaf
-	$self->{'characters'}->{'NAME'}->{$name} = charnames::string_vianame($name);
-	$self->{'characters'}->{'UNICODE'}->{'U1F341'} = charnames::string_vianame($name);
+    my $name = charnames::viacode(0x1F341);    # Maple Leaf
+    $self->{'characters'}->{'NAME'}->{$name} = charnames::string_vianame($name);
+    $self->{'characters'}->{'UNICODE'}->{'U1F341'} = charnames::string_vianame($name);
     foreach my $u ($start .. $finish) {
         $name = charnames::viacode($u);
-		next if ($name eq '');
-		my $char = charnames::string_vianame($name);
-		$char = '?' unless(defined($char));
-		$self->{'characters'}->{'NAME'}->{$name} = $char;
-		$self->{'characters'}->{'UNICODE'}->{sprintf('U%05X',$u)} = $char;
-    }
-	if ($self->{'mode'} =~ /full|long/i) {
-		$start = 0x1F300;
-		$finish = 0x1FBFF;
-		foreach my $u ($start .. $finish) {
-			$name = charnames::viacode($u);
-			next if ($name eq '');
-			my $char = charnames::string_vianame($name);
-			$char = '?' unless(defined($char));
-			$self->{'characters'}->{'NAME'}->{$name} = $char;
-			$self->{'characters'}->{'UNICODE'}->{sprintf('U%05X',$u)} = $char;
-		}
-	}
+        next if ($name eq '');
+        my $char = charnames::string_vianame($name);
+        $char = '?' unless (defined($char));
+        $self->{'characters'}->{'NAME'}->{$name} = $char;
+        $self->{'characters'}->{'UNICODE'}->{ sprintf('U%05X', $u) } = $char;
+    } ## end foreach my $u ($start .. $finish)
+    if ($self->{'mode'} =~ /full|long/i) {
+        $start  = 0x1F300;
+        $finish = 0x1FBFF;
+        foreach my $u ($start .. $finish) {
+            $name = charnames::viacode($u);
+            next if ($name eq '');
+            my $char = charnames::string_vianame($name);
+            $char = '?' unless (defined($char));
+            $self->{'characters'}->{'NAME'}->{$name} = $char;
+            $self->{'characters'}->{'UNICODE'}->{ sprintf('U%05X', $u) } = $char;
+        } ## end foreach my $u ($start .. $finish)
+    } ## end if ($self->{'mode'} =~...)
     bless($self, $class);
     return ($self);
 } ## end sub new
